@@ -8,10 +8,11 @@ import ast
 import multiprocessing
 import threading
 import datetime
-from multiprocessing.managers import BaseManager
+import copy
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 sys.path.append(BASE_DIR)
 import save_task
+from multiprocessing.managers import BaseManager
 from modules import board_manager
 from modules import queuelib
 from modules import log
@@ -79,7 +80,7 @@ class Server(object):
         self.sm.send_to_server(dead_msg)
 
     def tcp_bind(self):
-        port = 10000
+        port = 18889
         host = ''
         s = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
         s.bind((host,port))
@@ -166,20 +167,21 @@ class Server(object):
             usb_wifi = msg['message_content']['dvb_info']['auto_board']['usb_wifi']
             usb_wifi_type = msg['message_content']['dvb_info']['auto_board']['usb_wifi_type']
             priority = msg['message_content']['dvb_info']['auto_board']['priority']
+            secure = msg['message_content']['dvb_info']['auto_board']['secure']
             if msg['message_content']['dvb_ai'] == 'ai':
                 board = msg['message_content']['ai_info']['task_info']['board']
                 idle_boards = self.bc.get_idle_board_list(arch, chip, board, signal, usb_type)
             else:
                 idle_boards = self.bc.get_idle_board_list2(mode, arch, chip, board, signal,\
                         usb_device, usb_gxbus, usb_type, usb_partition_num, \
-                        web, usb_wifi, usb_wifi_type, priority)
+                        web, usb_wifi, usb_wifi_type, secure, priority)
             print(idle_boards)
             if len(idle_boards) > 0:
                 use_board = idle_boards.pop()
                 client_ip = use_board[0]
                 client_port = use_board[1]
                 board_name = use_board[2]
-                self.bc.update_board_status(use_board, 'busy')
+                #self.bc.update_board_status(use_board, 'busy')
                 self.board_change = 1
                 if msg['message_content']['dvb_ai'] == 'dvb': 
                     msg['message_content']['dvb_info']['specific_board']['client_ip'] \
@@ -309,8 +311,22 @@ class Server(object):
 
     def delete_task(self, msg):
         ret = 0
+        info = 'del success'
+        jenkins_name = msg['message_content']['jenkins_name']
+        jenkins_build = msg['message_content']['jenkins_build']
+        copy_list = copy.deepcopy(self.level1_msg_list)
+        try:
+            for i in copy_list:
+                if jenkins_name and i['message_content']['dvb_info']['testlink_info']\
+                        ['jenkins_project_name'] != jenkins_name:
+                    continue
+                if jenkins_build and i['message_content']['dvb_info']['testlink_info']\
+                        ['jenkins_build_id'] != jenkins_build:
+                    continue
+                self.level1_msg_list.remove(i)
+        except:
+            info = 'del failed'
         if msg['sync'] == True:
-            info = 'del success'
             msg['answer'] = str(info)
             self.sm.answer_msg(msg)
         return ret
@@ -339,7 +355,7 @@ class Server(object):
             msg['answer'] = str(info)
             self.sm.answer_msg(msg)
         return ret
-
+    
     def update_client_status(self, msg):
         ret = 0
         info = 'update success'
