@@ -3,23 +3,26 @@ import os
 import socket
 import threading
 import time
-import json
-import copy
-import argparse
-from getopt import getopt
+import datetime
+import fcntl
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 sys.path.append(BASE_DIR)
+import yaml
+import json
 import sendmsg
+import copy
+import argparse
 import ftp
 import msg
+from getopt import getopt
 
 class CmdBase(object):
     def __init__(self):
         self.udp_port = 28888
         self.time_format = "%Y-%m-%d %H:%M:%S"
         self.sm = sendmsg.SendMsg()
-        self.local_host = '192.168.110.244'
-        self.local_recv_port = 10001
+        self.local_host = '192.168.111.101'
+        self.local_recv_port = 10010
         self.read_log_port = 10003
         self.udp_host = self.local_host
         self.gm = msg.GenMsg()
@@ -47,8 +50,8 @@ class CmdBase(object):
         #return port
 
     def bind_tcp(self, host = '', port = ''):
-        host = '192.168.110.244'
-        port = 10000
+        host = '192.168.111.101'
+        port = 18889
         self.s = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
         self.s.connect((host,port))
 
@@ -58,10 +61,8 @@ class CmdBase(object):
         print('send success')
 
     def recv_log(self):
-        print(111111)
         port = self.read_log_port
         host = ''
-        print(port)
         msg = ''.encode()
         s = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
         s.bind((host,port))
@@ -76,7 +77,6 @@ class CmdBase(object):
                 break
 
     def recv_msg(self):
-        print(111111)
         port = self.local_recv_port
         host = ''
         msg = ''.encode()
@@ -88,6 +88,7 @@ class CmdBase(object):
         start = 0
         while True:
             data = sock.recv(1024)
+            print(data)
             if data.find('§§START§§'.encode()) >= 0:
                 start = 1
             if start:
@@ -430,14 +431,16 @@ class TaskManager(CmdBase):
         if sync:
             self.recv_msg()
 
-    def DelTask(self, sync, receiver, jenkins = '', ip = '', port='', board = '', chip=''):
+    def DelTask(self, sync, receiver, jenkins_name = '', jenkins_build = '', \
+            ip = '', port='', board = '', chip=''):
         receiver = 'server'
         message = copy.deepcopy(self.message_format)
         message['ip'] = self.local_host
         message['port'] = self.local_recv_port
         message['receiver'] = receiver
         content = {
-                'jenkins':jenkins,
+                'jenkins_name':jenkins_name,
+                'jenkins_build':jenkins_build,
                 'chip':chip,
                 'board':board,
                 'ip' : ip,
@@ -453,8 +456,8 @@ class TaskManager(CmdBase):
         if sync:
             self.recv_msg()
 
-    def DelTaskByJenkinsProject(self, sync, receiver, jenkins=''):
-        self.DelTask(sync, receiver, jenkins = jenkins)
+    def DelTaskByJenkinsProject(self, sync, receiver, jenkins_name ='', jenkins_build = ''):
+        self.DelTask(sync, receiver, jenkins_name = jenkins_name, jenkins_build = jenkins_build)
 
     def DelTaskByClient(self, sync, receiver, ip = '', port = ''):
         self.DelTask(sync, receiver, ip = ip, port = port)
@@ -469,8 +472,8 @@ class TaskManager(CmdBase):
             board = '', dvb = 'dvb', now = ''):
         if local_bin:
             fl = ftp.FtpFunctionLib(\
-                    Host = '192.168.110.253', UserName = 'guoxin', Password = 'Guoxin88156088',\
-                    FtpLoginBasicPath= 'public/ftp/AutoTestBin/' + dvb, LoginPort = 21)
+                    Host = '192.168.111.101', UserName = 'guoxin', Password = 'Guoxin88156088',\
+                    FtpLoginBasicPath= './' + dvb, LoginPort = 2121)
             ret = fl.FtpLogin()
             print(ret)
             if not jenkins_name:
@@ -490,20 +493,20 @@ class TaskManager(CmdBase):
             bin_url = dvb + '/' + remote_bin
         return bin_url
 
-    #def _renamefile(self):
-    #    fl = ftp.FtpFunctionLib(\
-    #            Host = '192.168.111.101', UserName = 'guoxin', Password = 'Guoxin88156088',\
-    #            FtpLoginBasicPath= './',  LoginPort = 2121)
-    #    ret = fl.FtpLogin()
-    #    print(ret)
-    #    local_file = '[STOP]'
-    #    os.system('touch a.txt')
-    #    remote_path = 'Test_Entrance'
-    #    remote_bin = remote_path + '/' + local_file
-    #    fl.Mkdirs(remote_path)
-    #    fl.UploadFile('a.txt', remote_bin)
-    #    fl.FtpQuit()
-    #    os.system('rm "' + local_file + '"')
+    def _renamefile(self):
+        fl = ftp.FtpFunctionLib(\
+                Host = '192.168.111.101', UserName = 'guoxin', Password = 'Guoxin88156088',\
+                FtpLoginBasicPath= './',  LoginPort = 2121)
+        ret = fl.FtpLogin()
+        print(ret)
+        local_file = '[STOP]'
+        os.system('touch a.txt')
+        remote_path = 'Test_Entrance'
+        remote_bin = remote_path + '/' + local_file
+        fl.Mkdirs(remote_path)
+        fl.UploadFile('a.txt', remote_bin)
+        fl.FtpQuit()
+        #os.system('rm "' + local_file + '"')
 
     def Start(self, sync, receiver,  dvb = '', local_bin = '', bin_url = '', \
             local_boot_file = '', boot_file_url = '', local_boot_tool = '',\
@@ -535,7 +538,7 @@ class TaskManager(CmdBase):
         content['dvb_info']['test_info']['boot_file_url'] = boot_file_url
         content['dvb_info']['test_info']['boot_tool_url'] = boot_tool_url
         content['dvb_info']['test_info']['os'] = bin_os
-        content['dvb_info']['test_info']['mode'] = mode
+        content['dvb_info']['auto_board']['mode'] = mode
         content['dvb_info']['auto_board']['arch'] = arch
         content['dvb_info']['auto_board']['chip'] = chip
         content['dvb_info']['auto_board']['board'] = board
@@ -573,7 +576,7 @@ class TaskManager(CmdBase):
             local_bin = '', bin_url = '', \
             jenkins_name = '', jenkins_build = '', board = '',
             gerrit_id = '', gerrit_patch = '', \
-            testlink_project = '', testlink_plan = '', testlink_build = ''):
+            testlink_project = '', testlink_plan = '', testlink_build = '', platform = ''):
         receiver = 'server'
         message = self.gm.msg_format()
         message['ip'] = self.local_host
@@ -589,6 +592,7 @@ class TaskManager(CmdBase):
         content['ai_info']['task_type'] = task_type
         content['ai_info']['task_info']['bin_url'] = bin_url
         content['ai_info']['task_info']['board'] = board
+        content['ai_info']['task_info']['platform'] = platform
         content['ai_info']['jenkins_info']['jenkins_project_name'] = jenkins_name
         content['ai_info']['jenkins_info']['jenkins_build_id'] = jenkins_build
         content['ai_info']['gerrit_info']['gerrit_id'] = gerrit_id
@@ -639,7 +643,7 @@ class TaskManager(CmdBase):
         self.close_tcp()
         if sync:
             self.recv_msg()
-        #self._renamefile()
+        self._renamefile()
 
     def ServerStash(self, sync, receiver):
         sync = True
@@ -679,7 +683,56 @@ class TaskManager(CmdBase):
         if sync:
             self.recv_msg()
 
-    def GetTestResult(self, sync, receiver, task):
+    def GetTestResult(self, sync, receiver, task, platform):
+        result_path = self._find_result(task, platform)
+        filename = self._download(result_path)
+        print("testreport_name:")
+        print(filename)
+        return filename
+
+    def _download(self, remote_path):
+        fl = ftp.FtpFunctionLib(\
+                Host = '192.168.111.101', UserName = 'guoxin', Password = 'Guoxin88156088',\
+                FtpLoginBasicPath= './',  LoginPort = 2121)
+        ret = fl.FtpLogin()
+        print('>>>>>>>>>>>>>>>>>>')
+        print(remote_path)
+        print('>>>>>>>>>>>>>>>>>>')
+        local_path = os.path.basename(remote_path)
+        fl.DownloadFile(remote_path, local_path)
+        fl.FtpQuit()
+        return local_path
+    
+    def _find_result(self, task_bin, platform):
+        task_dir_name = task_bin.split('.tar.gz')[0]
+        fl = ftp.FtpFunctionLib(\
+                Host = '192.168.111.101', UserName = 'guoxin', Password = 'Guoxin88156088',\
+                FtpLoginBasicPath= './',  LoginPort = 2121)
+        ret = fl.FtpLogin()
+        history_dir = os.path.join(platform, 'history')
+        file_list = fl.QueryRemoteFileList(history_dir)
+        print(111111111111111)
+        print(history_dir)
+        print(file_list)
+        result_path = None
+        excel_list = []
+        for i in file_list:
+            if i.endswith(task_dir_name):
+                result_path = history_dir + '/' + i + '/' + i
+                print('>>>>>>>>>>>>>>>')
+                print(result_path)
+                excel_list = fl.QueryRemoteFileList(result_path)
+                print(excel_list)
+                print('>>>>>>>>>>>>>>>')
+                break
+        for i in excel_list:
+            if i.endswith('xlsx'):
+                result_path += '/' + i
+        fl.FtpQuit()
+        return result_path
+
+
+    def GetTestResult2(self, sync, receiver, task):
         sync = True
         message = self.gm.msg_format()
         message['ip'] = self.local_host
@@ -915,7 +968,7 @@ def func_aiStart(args):
             args.local_bin, args.bin_url, \
             args.jenkins_name, args.jenkins_build, args.board, \
             args.gerrit_id, args.gerrit_patch, \
-            args.testlink_project, args.testlink_plan, args.testlink_build)
+            args.testlink_project, args.testlink_plan, args.testlink_build, args.platform)
 
 def func_Stop(args):
     taskmanager = TaskManager()
@@ -945,7 +998,8 @@ def func_DelAllTask(args):
 
 def func_DelTaskByJenkinsProject(args):
     taskmanager = TaskManager()
-    taskmanager.DelTaskByJenkinsProject(args.sync, args.receiver, args.jenkins)
+    taskmanager.DelTaskByJenkinsProject(args.sync, args.receiver, args.jenkins_name, \
+            jenkins_build)
 
 def func_DelTaskByClient(args):
     taskmanager = TaskManager()
@@ -997,8 +1051,9 @@ def func_ServerResume(args):
     taskmanager.ServerResume(args.sync, args.receiver)
 
 def func_GetTestResult(args):
+    print(888888888888888888)
     taskmanager = TaskManager()
-    taskmanager.GetTestResult(args.sync, args.receiver, args.task)
+    taskmanager.GetTestResult(args.sync, args.receiver, args.task, args.platform)
 
 def func_GetTestWav(args):
     fl = ftp.FtpFunctionLib(\
@@ -1009,6 +1064,83 @@ def func_GetTestWav(args):
     print(wavlist)
     fl.FtpQuit()
 
+def func_GetTestPlatformState(args):
+    fl = ftp.FtpFunctionLib(\
+            Host = '192.168.111.101', UserName = 'guoxin', Password = 'Guoxin88156088',\
+            FtpLoginBasicPath= './ai_algorithm', LoginPort = 2121)
+    fl.FtpLogin()
+    info = fl.get_test_platform_state()
+    fl.FtpQuit()
+    filename = 'platform_state.yaml'
+    with open(filename, 'w') as fd:
+        yaml.dump(info, fd, default_flow_style=False, indent = 4, allow_unicode=True)
+    print(info)
+
+def func_GetTaskState(args):
+    now_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
+    fl = ftp.FtpFunctionLib(\
+            Host = '192.168.111.101', UserName = 'guoxin', Password = 'Guoxin88156088',\
+            FtpLoginBasicPath= './', LoginPort = 2121)
+    fl.FtpLogin()
+    task_info = fl.get_task_info()
+    fl.FtpQuit()
+    task_yaml = '/home/wangshj/goxceed_web/gxtest/pctools/tools/web/static/upload/save_task.yaml'
+    with open(os.path.join(os.getcwd(),task_yaml), "r") as f:
+        fcntl.flock(f.fileno(), fcntl.LOCK_EX) #加锁
+        all_task = yaml.load(f)
+    print(all_task)
+    bind_msg = {}
+    bind_yaml = '/home/wangshj/goxceed_web/gxtest/pctools/tools/web/static/upload/bind_task.yaml'
+    if not os.path.exists(bind_yaml):
+        with open(bind_yaml, "w") as f:
+            f.write('{}\n')
+    with open(bind_yaml, 'r') as f:
+        bind_msg = yaml.load(f)
+    for task in task_info:
+        task_package = task['package']
+        for s_task in all_task['start']:
+            tid = task['package'] + task['platform'] + task['ftp_time']
+            print(777777777777777777777)
+            print(s_task)
+            print(tid)
+            print(s_task['package'] + s_task['platform'] + s_task['start_time'])
+            print(777777777777777777777)
+            if s_task['package'] == task['package'] and \
+                    s_task['platform'] == task['platform'] and s_task['state'] != 'finish':
+                if tid not in bind_msg: #未绑定web端的任务
+                    print(11111111111111111111111)
+                    bind_msg[tid] = 'true'
+                    print(">>>>>>>>>>>>>>>>>>")
+                    print(tid)
+                    print(">>>>>>>>>>>>>>>>>>")
+                    if s_task['state'] == 'waiting' and task['state'] == 'running':
+                        s_task['start_time'] = task['ftp_time']
+                        s_task['state'] = task['state']
+                        s_task['running_wav'] = task['running_wav']
+                        s_task['percent'] = s_task['running_wav']*100 / s_task['all_wav']
+                        timep1 = datetime.datetime.strptime(s_task['start_time'], "%Y-%m-%d-%H-%M-%S") 
+                        timep2 = datetime.datetime.strptime(now_time, "%Y-%m-%d %H:%M:%S") 
+                        s_task['running_time'] = str(timep2 - timep1)
+                else: #已绑定web端的任务
+                    print(21111111111111111111111)
+                    print(s_task['start_time'])
+                    print(task['ftp_time'])
+                    if s_task['start_time'] != task['ftp_time']: #不是绑定的任务
+                        print(31111111111111111111111)
+                        continue
+                    print(41111111111111111111111)
+                    s_task['state'] = task['state']
+                    s_task['running_wav'] = task['running_wav']
+                    s_task['percent'] = s_task['running_wav']*100 / s_task['all_wav']
+                    timep1 = datetime.datetime.strptime(s_task['start_time'], "%Y-%m-%d-%H-%M-%S") 
+                    timep2 = datetime.datetime.strptime(now_time, "%Y-%m-%d %H:%M:%S") 
+                    s_task['running_time'] = str(timep2 - timep1)
+    with open(task_yaml, "w") as f:
+        fcntl.flock(f.fileno(), fcntl.LOCK_EX) #加锁
+        yaml.dump(all_task, f, default_flow_style=False, indent = 4, allow_unicode=True)
+    with open(bind_yaml, "w") as f:
+        yaml.dump(bind_msg, f, default_flow_style=False, indent = 4, allow_unicode=True)
+
 def main():
     parent_parser = argparse.ArgumentParser(add_help = False)
     #parser.add_argument('-s', '--sync', dest = 'SYNC', default=False, help='是否为同步消息')
@@ -1124,6 +1256,7 @@ def main():
     cmd_Start.add_argument('-lb', dest = 'local_bin', type = str, help='指定本地bin文件')
     cmd_Start.add_argument('-burl', dest = 'bin_url', type = str, \
             help='指定bin文件所在的ftp路径')
+    cmd_Start.add_argument('-p', dest = 'platform', type = str, help='指定测试平台')
     cmd_Start.add_argument('-jn', dest = 'jenkins_name', type = str, help='指定jenkins名称')
     cmd_Start.add_argument('-jb', dest = 'jenkins_build', type = str, help='指定jenkins构建')
     cmd_Start.add_argument('-b', dest = 'board', type = str, help='板子类型')
@@ -1224,8 +1357,10 @@ def main():
     #添加子命令 DelTaskByJenkinsProject
     cmd_DelTaskByJenkinsProject = subparsers.add_parser('DelTaskByJenkinsProject', \
             help='删除jenkins任务', parents = [parent_parser])
-    cmd_DelTaskByJenkinsProject.add_argument('-j', dest = 'jenkins', type = str, \
-            help='jenkins项目')
+    cmd_DelTaskByJenkinsProject.add_argument('-jn', dest = 'jenkins_name', type = str, \
+            help='指定jenkins项目名称')
+    cmd_DelTaskByJenkinsProject.add_argument('-jb', dest = 'jenkins_build', type = str, \
+            help='指定jenkins构建')
     cmd_DelTaskByJenkinsProject.set_defaults(func = func_DelTaskByJenkinsProject)
     #添加子命令 DelTaskByClient
     cmd_DelTaskByClient = subparsers.add_parser('DelTaskByClient', \
@@ -1311,11 +1446,20 @@ def main():
     cmd_GetTestResult = subparsers.add_parser('GetTestResult', \
             help='获取测试结果', parents = [parent_parser])
     cmd_GetTestResult.add_argument('-t', dest = 'task', type = str, help='指定测试任务')
+    cmd_GetTestResult.add_argument('-p', dest = 'platform', type = str, help='指定测试平台')
     cmd_GetTestResult.set_defaults(func = func_GetTestResult)
-    #添加子命令 GetTestWav
-    cmd_GetTestWav = subparsers.add_parser('GetTestWav', \
-            help='获取测试语料', parents = [parent_parser])
-    cmd_GetTestWav.set_defaults(func = func_GetTestWav)
+    ##添加子命令 GetTestWav
+    #cmd_GetTestWav = subparsers.add_parser('GetTestWav', \
+    #        help='获取测试语料', parents = [parent_parser])
+    #cmd_GetTestWav.set_defaults(func = func_GetTestWav)
+    #添加子命令 GetTestPlatformState
+    cmd_GetTestPlatformState = subparsers.add_parser('GetTestPlatformState', \
+            help='查询测试平台状态', parents = [parent_parser])
+    cmd_GetTestPlatformState.set_defaults(func = func_GetTestPlatformState)
+    #添加子命令 GetTaskState
+    cmd_GetTaskState = subparsers.add_parser('GetTaskState', \
+            help='查询任务执行状态', parents = [parent_parser])
+    cmd_GetTaskState.set_defaults(func = func_GetTaskState)
 
     
     args = parser.parse_args()
